@@ -20,8 +20,8 @@ munits.registry[datetime] = converter
 
 
 def tplot(variables, var_label=None,
-                     xsize=8, 
-                     ysize=10, 
+                     xsize=None,
+                     ysize=None,
                      save_png='', 
                      save_eps='', 
                      save_svg='', 
@@ -58,7 +58,12 @@ def tplot(variables, var_label=None,
             if variable > len(tnames):
                 print('Variable not found: ' + str(variable))
             variables[idx] = tnames[variable]
-        
+
+    # support for matplotlib styles
+    style = pytplot.tplot_opt_glob.get('style')
+    if style is not None:
+        plt.style.use(style)
+
     num_panels = len(variables)
     panel_sizes = [1]*num_panels
 
@@ -70,6 +75,16 @@ def tplot(variables, var_label=None,
         if panel_size is not None:
             panel_sizes[var_idx] = panel_size
 
+    if xsize is None:
+        xsize = pytplot.tplot_opt_glob.get('xsize')
+        if xsize is None:
+            xsize = 8
+
+    if ysize is None:
+        ysize = pytplot.tplot_opt_glob.get('ysize')
+        if ysize is None:
+            ysize = 10
+
     if fig is None and axis is None:
         fig, axes = plt.subplots(nrows=num_panels, sharex=True, gridspec_kw={'height_ratios': panel_sizes})
         fig.set_size_inches(xsize, ysize)
@@ -105,6 +120,7 @@ def tplot(variables, var_label=None,
     
     for idx, variable in enumerate(variables):
         var_data_org = pytplot.get_data(variable, dt=True)
+        var_metadata = pytplot.get_data(variable, metadata=True)
         
         if var_data_org is None:
             print('Variable not found: ' + variable)
@@ -185,6 +201,19 @@ def tplot(variables, var_label=None,
         # set the x-axis range, if it was set with xlim or tlimit
         if pytplot.tplot_opt_glob.get('x_range') is not None:
             x_range = pytplot.tplot_opt_glob['x_range']
+
+            if isinstance(x_range[0], float):
+                if np.isfinite(x_range[0]):
+                    x_range[0] = datetime.utcfromtimestamp(x_range[0])
+                else:
+                    x_range[0] = datetime.utcfromtimestamp(0)
+
+            if isinstance(x_range[1], float):
+                if np.isfinite(x_range[1]):
+                    x_range[1] = datetime.utcfromtimestamp(x_range[1])
+                else:
+                    x_range[1] = datetime.utcfromtimestamp(0)
+
             x_range = np.array(x_range, dtype='datetime64[s]')
             this_axis.set_xlim(x_range)
             time_idxs = np.argwhere((var_data.times >= x_range[0]) & (var_data.times <= x_range[1])).flatten()
@@ -231,12 +260,18 @@ def tplot(variables, var_label=None,
         ysubtitle = ''
         if yaxis_options.get('axis_subtitle') is not None:
             ysubtitle = yaxis_options['axis_subtitle']
-            
+
+        # replace some common superscripts
+        ysubtitle = replace_common_exp(ysubtitle)
+
         if axis_font_size is not None:
             this_axis.tick_params(axis='x', labelsize=axis_font_size)
             this_axis.tick_params(axis='y', labelsize=axis_font_size)
 
-        char_size = 14
+        char_size = pytplot.tplot_opt_glob.get('charsize')
+        if char_size is None:
+            char_size = 12
+
         if plot_extras.get('char_size') is not None:
             char_size = plot_extras['char_size']
 
@@ -250,11 +285,18 @@ def tplot(variables, var_label=None,
                 yrange[1] = None
             this_axis.set_ylim(yrange)
 
-        ytitle_color = 'black'
+        if style is None:
+            ytitle_color = 'black'
+        else:
+            ytitle_color = None
+
         if yaxis_options.get('axis_color') is not None:
             ytitle_color = yaxis_options['axis_color']
 
-        this_axis.set_ylabel(ytitle + '\n' + ysubtitle, fontsize=char_size, color=ytitle_color)
+        if ytitle_color is not None:
+            this_axis.set_ylabel(ytitle + '\n' + ysubtitle, fontsize=char_size, color=ytitle_color)
+        else:
+            this_axis.set_ylabel(ytitle + '\n' + ysubtitle, fontsize=char_size)
 
         border = True
         if plot_extras.get('border') is not None:
@@ -301,12 +343,12 @@ def tplot(variables, var_label=None,
 
         if spec:
             # create spectrogram plots
-            plot_created = specplot(var_data, var_times, this_axis, yaxis_options, zaxis_options, plot_extras, colorbars, axis_font_size, fig, variable, time_idxs=time_idxs)
+            plot_created = specplot(var_data, var_times, this_axis, yaxis_options, zaxis_options, plot_extras, colorbars, axis_font_size, fig, variable, time_idxs=time_idxs, style=style)
             if not plot_created:
                 continue
         else:
             # create line plots
-            plot_created = lineplot(var_data, var_times, this_axis, line_opts, yaxis_options, plot_extras, pseudo_plot_num=pseudo_plot_num, time_idxs=time_idxs)
+            plot_created = lineplot(var_data, var_times, this_axis, line_opts, yaxis_options, plot_extras, pseudo_plot_num=pseudo_plot_num, time_idxs=time_idxs, style=style, var_metadata=var_metadata)
             if not plot_created:
                 continue
             
@@ -415,11 +457,27 @@ def tplot(variables, var_label=None,
                 cax.tick_params(labelsize=colorbars[variable]['axis_font_size'])
             colorbar = fig.colorbar(colorbars[variable]['im'], cax=cax)
 
-            ztitle_color = 'black'
+            if style is None:
+                ztitle_color = 'black'
+            else:
+                ztitle_color = None
+
             if zaxis_options.get('axis_color') is not None:
                 ztitle_color = zaxis_options['axis_color']
 
-            colorbar.set_label(colorbars[variable]['ztitle'] + '\n ' + colorbars[variable]['zsubtitle'], color=ztitle_color, fontsize=char_size)
+            ztitle_text = colorbars[variable]['ztitle']
+            zsubtitle_text = colorbars[variable]['zsubtitle']
+
+            # replace some common superscripts
+            ztitle_text = replace_common_exp(ztitle_text)
+            zsubtitle_text = replace_common_exp(zsubtitle_text)
+
+            if ztitle_color is not None:
+                colorbar.set_label(ztitle_text + '\n ' + zsubtitle_text,
+                                   color=ztitle_color, fontsize=char_size)
+            else:
+                colorbar.set_label(ztitle_text + '\n ' + zsubtitle_text,
+                                   fontsize=char_size)
 
     if return_plot_objects:
         return fig, axes
@@ -550,3 +608,29 @@ def get_var_label_ticks(var_xr, times):
     for time in times:
         out_ticks.append('{:.2f}'.format(var_xr.interp(coords={'time': time}, kwargs={'fill_value': 'extrapolate', 'bounds_error': False}).values))
     return out_ticks
+
+
+def replace_common_exp(title):
+    if '$' in title:
+        return title
+    if '^' not in title:
+        return title
+    exp = False
+    title_out = ''
+    for char in title:
+        if char == '^':
+            exp = True
+            title_out += '$^{'
+            continue
+        else:
+            if exp:
+                if not char.isalnum():
+                    title_out += '}$' + char
+                    exp = False
+                    continue
+        title_out += char
+    if exp:
+        title_out += '}$'
+    return title_out
+
+
